<?php
/**
 * Copyright © FiloBlu S.p.A. 2019. All rights reserved.
 */

namespace FiloBlu\Rma\Plugin\Helper;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Sales\Api\OrderRepositoryInterface;
use Psr\Log\LoggerInterface;

class Data
{
    /**
     * @var ScopeConfigInterface 
     */
    protected $scopeConfig;
    /**
     * @var OrderRepositoryInterface
     */
    protected $orderRepository;

    /**
     * @var LoggerInterface
     */
    protected $logger;


    const XML_PATH_VALIDITY_DAYS ='sales/rma_validity_settings/validity_days';
    //const XML_PATH_DAYS_AUTO_APPROVAL ='sales/rma_validity_settings/automatic_approval';


    /**
     * Data constructor.
     * @param ScopeConfigInterface $scopeConfig
     * @param OrderRepositoryInterface $orderRepository
     * @param LoggerInterface $logger
     */
    public function __construct(ScopeConfigInterface $scopeConfig,
                                OrderRepositoryInterface $orderRepository,
                                LoggerInterface $logger){
        
        $this->scopeConfig = $scopeConfig;
        $this->orderRepository = $orderRepository;
        $this->logger = $logger;

    }


    /**
     * @param $order
     * @return bool
     */
    public function isValid($order)
    {
        //error_log(__METHOD__);

        $validity_days = $this->scopeConfig->getValue(
            self::XML_PATH_VALIDITY_DAYS,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );

       try{
           if(is_int($order)){
               $order = $this->orderRepository->get($order);
           }

           $orderDate = $order->getCreatedAt(); //2019-11-06 13:17:01
           $dateTimeCreated = new \DateTime($orderDate);
           $dateTimeValidityEnds = $dateTimeCreated;
           $dateTimeValidityEnds->modify('+'.$validity_days.' day');
           $today = new \DateTime();
           if($today <= $dateTimeValidityEnds){
               return true;
           }else{
               return false;
           }


       }catch (\Throwable $throwable){
           $this->logger->critical($throwable->getMessage());
           return false;
       }catch (\Exception $e){
           $this->logger->critical($e->getMessage());
           return false;
       }



    }


    /** Magento 2.1 has problem with after plugin with arguments
     * @param \Magento\Rma\Helper\Data $subject
     * @param callable $proceed
     * @param $order
     * @param bool $forceCreate
     * @return bool
     */
    public function aroundCanCreateRma(\Magento\Rma\Helper\Data $subject , callable $proceed, $order, $forceCreate = false)
    {
        $result = $proceed($order,$forceCreate);

        if($forceCreate == true){
            return $forceCreate;
        }
        if(!$result){
            return $result;
        }else{
            $result = $this->isValid($order);
            return $result;
        }
    }

}
